.. gspider documentation master file, created by
   sphinx-quickstart on Fri Mar 20 00:07:27 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to gspider's documentation!
===================================
